@@ -128,6 +128,7 @@ class MyCnfRender(object):
         self.sync_binlog = 1
         self.binlog_stmt_cache_size = '32K'
         self.log_slave_updates = 'ON'
+        self.binlog_transaction_compression = 'ON'
         self.binlog_group_commit_sync_delay = 0
         self.binlog_group_commit_sync_no_delay_count = 0
         self.binlog_cache_size = '96K'
@@ -416,6 +417,13 @@ class MyCnfRender(object):
             self.innodb_log_file_size = '256M'
             self.innodb_log_buffer_size = '2G'
 
+        # 设置最大连接数
+        self.max_connections = chunk * 8
+        if self.max_connections <= 128:
+            self.max_connections = 128
+        elif self.max_connections >= 2048:
+            self.max_connections = 2048
+
     def _config_disk(self):
         """
         磁盘目前还不做配置
